@@ -2,7 +2,7 @@ use gfaR::{Node, readGFA};
 // cargo test -- --nocapture
 #[test]
 fn it_adds_two() {
-    let n: Node = Node { id: "dsadka".to_owned(), len: 10 };
+    let n: Node = Node { id: "dsadka".to_owned(), len: 10 , seq: "AAT".to_owned()};
     let u = readGFA("dasdsa");
 
     println!("{:?}", u.edges.len());
